@@ -78,7 +78,7 @@ int main(int argc, char *argv[])
 
     KLocalizedString::setApplicationDomain("krfb");
 
-    KAboutData aboutData("krfb",
+    KAboutData aboutData(QStringLiteral("krfb"),
                          i18n("Desktop Sharing"),
                          QStringLiteral(KRFB_VERSION_STRING),
                          i18n(description),
@@ -92,12 +92,12 @@ int main(int argc, char *argv[])
                                "(c) 1999, AT&T Laboratories Boston\n"));
     aboutData.addAuthor(i18n("George Goldberg"),
                         i18n("Telepathy tubes support"),
-                        "george.goldberg@collabora.co.uk");
+                        QStringLiteral("george.goldberg@collabora.co.uk"));
     aboutData.addAuthor(i18n("George Kiagiadakis"),
                         QString(),
-                        "george.kiagiadakis@collabora.co.uk");
-    aboutData.addAuthor(i18n("Alessandro Praduroux"), i18n("KDE4 porting"), "pradu@pradu.it");
-    aboutData.addAuthor(i18n("Tim Jansen"), i18n("Original author"), "tim@tjansen.de");
+                        QStringLiteral("george.kiagiadakis@collabora.co.uk"));
+    aboutData.addAuthor(i18n("Alessandro Praduroux"), i18n("KDE4 porting"), QStringLiteral("pradu@pradu.it"));
+    aboutData.addAuthor(i18n("Tim Jansen"), i18n("Original author"), QStringLiteral("tim@tjansen.de"));
     aboutData.addCredit(i18n("Johannes E. Schindelin"),
                         i18n("libvncserver"));
     aboutData.addCredit(i18n("Const Kaplinsky"),
@@ -107,18 +107,18 @@ int main(int argc, char *argv[])
     aboutData.addCredit(i18n("AT&T Laboratories Boston"),
                         i18n("original VNC encoders and "
                               "protocol design"));
-    QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
-    parser.addVersionOption();
-    parser.addHelpOption();
+
+    QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
+    const QCommandLineOption nodialogOption(QStringList{ QStringLiteral("nodialog") }, i18n("Do not show the invitations management dialog at startup"));
+    parser.addOption(nodialogOption);
+
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
     KDBusService service(KDBusService::Unique, &app);
 
-    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("nodialog"), i18n("Do not show the invitations management dialog at startup")));
-
     app.setQuitOnLastWindowClosed(false);
 
     if (!checkX11Capabilities()) {
@@ -139,7 +139,7 @@ int main(int argc, char *argv[])
       mainWindow.hide();
     } else if (app.isSessionRestored() && KMainWindow::canBeRestored(1)) {
         mainWindow.restore(1, false);
-    } else if (!parser.isSet("nodialog")) {
+    } else if (!parser.isSet(nodialogOption)) {
         mainWindow.show();
     }
 
